@@ -42,6 +42,7 @@
 #include "gedit-print-preview.h"
 #include "gedit-marshal.h"
 #include "gedit-utils.h"
+#include "gedit-dirs.h"
 
 
 #define GEDIT_PRINT_JOB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
@@ -155,8 +156,6 @@ gedit_print_job_finalize (GObject *object)
 {
 	GeditPrintJob *job = GEDIT_PRINT_JOB (object);
 
-	g_debug ("Finalize.");
-	
 	g_free (job->priv->status_string);
 	
 	if (job->priv->compositor != NULL)
@@ -313,27 +312,35 @@ create_custom_widget_cb (GtkPrintOperation *operation,
 	gint line_numbers;
 	gboolean can_set;
 	GtkWrapMode wrap_mode;
+	gchar *file;
+	gchar *root_objects[] = {
+		"adjustment1",
+		"contents",
+		NULL
+	};
 
-	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "gedit-print-preferences.glade",
-					     "contents",
-					     &error_widget,
-					     "contents", &widget,
-					     "syntax_checkbutton", &job->priv->syntax_checkbutton,
-					     "line_numbers_checkbutton", &job->priv->line_numbers_checkbutton,
-					     "line_numbers_hbox", &job->priv->line_numbers_hbox,
-					     "line_numbers_spinbutton", &job->priv->line_numbers_spinbutton,
-					     "page_header_checkbutton", &job->priv->page_header_checkbutton,
-					     "text_wrapping_checkbutton", &job->priv->text_wrapping_checkbutton,
-					     "do_not_split_checkbutton", &job->priv->do_not_split_checkbutton,
-					     "fonts_table", &job->priv->fonts_table,
-					     "body_font_label", &job->priv->body_font_label,
-					     "body_fontbutton", &job->priv->body_fontbutton,
-					     "headers_font_label", &job->priv->headers_font_label,
-					     "headers_fontbutton", &job->priv->headers_fontbutton,
-					     "numbers_font_label", &job->priv->numbers_font_label,
-					     "numbers_fontbutton", &job->priv->numbers_fontbutton,
-					     "restore_button", &job->priv->restore_button,
-					     NULL);
+	file = gedit_dirs_get_ui_file ("gedit-print-preferences.ui");
+	ret = gedit_utils_get_ui_objects (file,
+					  root_objects,
+					  &error_widget,
+					  "contents", &widget,
+					  "syntax_checkbutton", &job->priv->syntax_checkbutton,
+					  "line_numbers_checkbutton", &job->priv->line_numbers_checkbutton,
+					  "line_numbers_hbox", &job->priv->line_numbers_hbox,
+					  "line_numbers_spinbutton", &job->priv->line_numbers_spinbutton,
+					  "page_header_checkbutton", &job->priv->page_header_checkbutton,
+					  "text_wrapping_checkbutton", &job->priv->text_wrapping_checkbutton,
+					  "do_not_split_checkbutton", &job->priv->do_not_split_checkbutton,
+					  "fonts_table", &job->priv->fonts_table,
+					  "body_font_label", &job->priv->body_font_label,
+					  "body_fontbutton", &job->priv->body_fontbutton,
+					  "headers_font_label", &job->priv->headers_font_label,
+					  "headers_fontbutton", &job->priv->headers_fontbutton,
+					  "numbers_font_label", &job->priv->numbers_font_label,
+					  "numbers_fontbutton", &job->priv->numbers_fontbutton,
+					  "restore_button", &job->priv->restore_button,
+					  NULL);
+	g_free (file);
 
 	if (!ret)
 	{
@@ -668,7 +675,6 @@ end_print_cb (GtkPrintOperation *operation,
 	      GtkPrintContext   *context,
 	      GeditPrintJob     *job)
 {
-	g_debug ("end_print_cb");
 	g_object_unref (job->priv->compositor);
 	job->priv->compositor = NULL;
 }
@@ -681,8 +687,6 @@ done_cb (GtkPrintOperation       *operation,
 	GError *error = NULL;
 	GeditPrintJobResult print_result;
 
-	g_debug ("done_cb");
-	
 	switch (result) 
 	{
 		case GTK_PRINT_OPERATION_RESULT_CANCEL:
